Struct libp2p::core::connection::Connection [−][src]
pub struct Connection<TMuxer, THandler> where
THandler: ConnectionHandler<Substream = SubstreamRef<Arc<TMuxer>>>,
TMuxer: StreamMuxer, { /* fields omitted */ }Expand description
A multiplexed connection to a peer with an associated ConnectionHandler.
Implementations
impl<TMuxer, THandler> Connection<TMuxer, THandler> where
THandler: ConnectionHandler<Substream = SubstreamRef<Arc<TMuxer>>>,
TMuxer: StreamMuxer, [src]
impl<TMuxer, THandler> Connection<TMuxer, THandler> where
THandler: ConnectionHandler<Substream = SubstreamRef<Arc<TMuxer>>>,
TMuxer: StreamMuxer, [src]Builds a new Connection from the given substream multiplexer
and connection handler.
Returns a mutable reference to the ConnectionHandler
Notifies the connection handler of an event.
Begins an orderly shutdown of the connection, returning a
Future that resolves when connection shutdown is complete.
pub fn poll(
self: Pin<&mut Connection<TMuxer, THandler>>,
cx: &mut Context<'_>
) -> Poll<Result<Event<<THandler as ConnectionHandler>::OutEvent>, ConnectionError<<THandler as ConnectionHandler>::Error>>>[src]
pub fn poll(
self: Pin<&mut Connection<TMuxer, THandler>>,
cx: &mut Context<'_>
) -> Poll<Result<Event<<THandler as ConnectionHandler>::OutEvent>, ConnectionError<<THandler as ConnectionHandler>::Error>>>[src]Polls the connection for events produced by the associated handler as a result of I/O activity on the substream multiplexer.