Enum libp2p::core::muxing::StreamMuxerEvent [−][src]
pub enum StreamMuxerEvent<T> {
InboundSubstream(T),
AddressChange(Multiaddr),
}Expand description
Event about a connection, reported by an implementation of StreamMuxer.
Variants
Remote has opened a new substream. Contains the substream in question.
AddressChange(Multiaddr)Address to the remote has changed. The previous one is now obsolete.
Note: This can for example happen when using the QUIC protocol, where the two nodes can change their IP address while retaining the same QUIC connection.
Implementations
If self is a StreamMuxerEvent::InboundSubstream, returns the content. Otherwise
returns None.