Struct libp2p::core::network::NetworkConfig [−][src]
pub struct NetworkConfig { /* fields omitted */ }Expand description
The (optional) configuration for a Network.
The default configuration specifies no dedicated task executor, no
connection limits, a connection event buffer size of 32, and a
notify_handler buffer size of 8.
Implementations
Configures the executor to use for spawning connection background tasks.
pub fn or_else_with_executor<F>(self, f: F) -> NetworkConfig where
F: FnOnce() -> Option<Box<dyn Executor + 'static + Send, Global>>, [src]
pub fn or_else_with_executor<F>(self, f: F) -> NetworkConfig where
F: FnOnce() -> Option<Box<dyn Executor + 'static + Send, Global>>, [src]Configures the executor to use for spawning connection background tasks, only if no executor has already been configured.
Sets the maximum number of events sent to a connection’s background task that may be buffered, if the task cannot keep up with their consumption and delivery to the connection handler.
When the buffer for a particular connection is full, notify_handler will no
longer be able to deliver events to the associated ConnectionHandler,
thus exerting back-pressure on the connection and peer API.
Sets the maximum number of buffered connection events (beyond a guaranteed buffer of 1 event per connection).
When the buffer is full, the background tasks of all connections will stall. In this way, the consumers of network events exert back-pressure on the network connection I/O.
Sets the connection limits to enforce.