Struct libp2p::core::transport::timeout::TransportTimeout [−][src]
pub struct TransportTimeout<InnerTrans> { /* fields omitted */ }Expand description
A TransportTimeout is a Transport that wraps another Transport and adds
timeouts to all inbound and outbound connection attempts.
Note: listen_on is never subject to a timeout, only the setup of each
individual accepted connection.
Implementations
Wraps around a Transport to add timeouts to all the sockets created by it.
pub fn with_outgoing_timeout(
trans: InnerTrans,
timeout: Duration
) -> TransportTimeout<InnerTrans>[src]
pub fn with_outgoing_timeout(
trans: InnerTrans,
timeout: Duration
) -> TransportTimeout<InnerTrans>[src]Wraps around a Transport to add timeouts to the outgoing connections.
pub fn with_ingoing_timeout(
trans: InnerTrans,
timeout: Duration
) -> TransportTimeout<InnerTrans>[src]
pub fn with_ingoing_timeout(
trans: InnerTrans,
timeout: Duration
) -> TransportTimeout<InnerTrans>[src]Wraps around a Transport to add timeouts to the ingoing connections.