Enum libp2p::core::upgrade::NegotiationError [−]
pub enum NegotiationError {
ProtocolError(ProtocolError),
Failed,
}Expand description
Error that can happen when negotiating a protocol with the remote.
Variants
ProtocolError(ProtocolError)A protocol error occurred during the negotiation.
Protocol negotiation failed because no protocol could be agreed upon.