Struct libp2p::deflate::DeflateConfig [−][src]
pub struct DeflateConfig { /* fields omitted */ }Trait Implementations
Returns the “default value” for a type. Read more
type Output = DeflateOutput<C>
type Output = DeflateOutput<C>Output after the upgrade has been successfully negotiated and the handshake performed.
type Future = Ready<Result<<DeflateConfig as InboundUpgrade<C>>::Output, <DeflateConfig as InboundUpgrade<C>>::Error>>
type Future = Ready<Result<<DeflateConfig as InboundUpgrade<C>>::Output, <DeflateConfig as InboundUpgrade<C>>::Error>>Future that performs the handshake with the remote.
pub fn upgrade_inbound(
self,
r: C,
<DeflateConfig as UpgradeInfo>::Info
) -> <DeflateConfig as InboundUpgrade<C>>::Future[src]
pub fn upgrade_inbound(
self,
r: C,
<DeflateConfig as UpgradeInfo>::Info
) -> <DeflateConfig as InboundUpgrade<C>>::Future[src]After we have determined that the remote supports one of the protocols we support, this method is called to start the handshake. Read more
type Output = DeflateOutput<C>
type Output = DeflateOutput<C>Output after the upgrade has been successfully negotiated and the handshake performed.
type Future = Ready<Result<<DeflateConfig as OutboundUpgrade<C>>::Output, <DeflateConfig as OutboundUpgrade<C>>::Error>>
type Future = Ready<Result<<DeflateConfig as OutboundUpgrade<C>>::Output, <DeflateConfig as OutboundUpgrade<C>>::Error>>Future that performs the handshake with the remote.
pub fn upgrade_outbound(
self,
w: C,
<DeflateConfig as UpgradeInfo>::Info
) -> <DeflateConfig as OutboundUpgrade<C>>::Future[src]
pub fn upgrade_outbound(
self,
w: C,
<DeflateConfig as UpgradeInfo>::Info
) -> <DeflateConfig as OutboundUpgrade<C>>::Future[src]After we have determined that the remote supports one of the protocols we support, this method is called to start the handshake. Read more
type Info = &'static [u8]
type Info = &'static [u8]Opaque type representing a negotiable protocol.
type InfoIter = Once<<DeflateConfig as UpgradeInfo>::Info>
type InfoIter = Once<<DeflateConfig as UpgradeInfo>::Info>Iterator returned by protocol_info.
Returns the list of protocols that are supported. Used during the negotiation process.