Struct libp2p::floodsub::FloodsubConfig [−][src]
Configuration options for the Floodsub protocol.
Fields
local_peer_id: PeerIdPeer id of the local node. Used for the source of the messages that we publish.
subscribe_local_messages: booltrue if messages published by local node should be propagated as messages received from
the network, false by default.
Implementations