Struct libp2p::floodsub::FloodsubMessage [−][src]
pub struct FloodsubMessage {
pub source: PeerId,
pub data: Vec<u8, Global>,
pub sequence_number: Vec<u8, Global>,
pub topics: Vec<Topic, Global>,
}Expand description
A message received by the floodsub system.
Fields
source: PeerIdId of the peer that published this message.
data: Vec<u8, Global>Content of the message. Its meaning is out of scope of this library.
sequence_number: Vec<u8, Global>An incrementing sequence number.
topics: Vec<Topic, Global>List of topics this message belongs to.
Each message can belong to multiple topics at once.