Enum libp2p::gossipsub::error::GossipsubHandlerError [−][src]
pub enum GossipsubHandlerError {
MaxInboundSubstreams,
MaxOutboundSubstreams,
MaxTransmissionSize,
NegotiationTimeout,
NegotiationProtocolError(ProtocolError),
Io(Error),
}Expand description
Errors that can occur in the protocols handler.
Variants
The maximum number of inbound substreams created has been exceeded.
The maximum number of outbound substreams created has been exceeded.
The message exceeds the maximum transmission size.
Protocol negotiation timeout.
NegotiationProtocolError(ProtocolError)Protocol negotiation failed.
Io(Error)IO error.