Enum libp2p::gossipsub::error::ValidationError [−][src]
pub enum ValidationError {
InvalidSignature,
EmptySequenceNumber,
InvalidSequenceNumber,
InvalidPeerId,
SignaturePresent,
SequenceNumberPresent,
MessageSourcePresent,
TransformFailed,
}Variants
The message has an invalid signature,
The sequence number was empty, expected a value.
The sequence number was the incorrect size
The PeerId was invalid
Signature existed when validation has been sent to
crate::behaviour::MessageAuthenticity::Anonymous.
Sequence number existed when validation has been sent to
crate::behaviour::MessageAuthenticity::Anonymous.
Message source existed when validation has been sent to
crate::behaviour::MessageAuthenticity::Anonymous.
The data transformation failed.