Enum libp2p::identify::IdentifyEvent[][src]

pub enum IdentifyEvent {
    Received {
        peer_id: PeerId,
        info: IdentifyInfo,
        observed_addr: Multiaddr,
    },
    Sent {
        peer_id: PeerId,
    },
    Error {
        peer_id: PeerId,
        error: ProtocolsHandlerUpgrErr<ReadOneError>,
    },
}
Event emitted by the Identify behaviour.

Variants

Received

Identifying information has been received from a peer.

Show fields

Fields of Received

peer_id: PeerId

The peer that has been identified.

info: IdentifyInfo

The information provided by the peer.

observed_addr: Multiaddr

The address observed by the peer for the local node.

Sent

Identifying information of the local node has been sent to a peer.

Show fields

Fields of Sent

peer_id: PeerId

The peer that the information has been sent to.

Error

Error while attempting to identify the remote.

Show fields

Fields of Error

peer_id: PeerId

The peer with whom the error originated.

error: ProtocolsHandlerUpgrErr<ReadOneError>

The error that occurred.