Struct libp2p::identify::IdentifyInfo [−][src]
pub struct IdentifyInfo {
pub public_key: PublicKey,
pub protocol_version: String,
pub agent_version: String,
pub listen_addrs: Vec<Multiaddr, Global>,
pub protocols: Vec<String, Global>,
}Expand description
Information of a peer sent in Identify protocol responses.
Fields
public_key: PublicKeyThe public key underlying the peer’s PeerId.
protocol_version: StringVersion of the protocol family used by the peer, e.g. ipfs/1.0.0
or polkadot/1.0.0.
agent_version: StringName and version of the peer, similar to the User-Agent header in
the HTTP protocol.
listen_addrs: Vec<Multiaddr, Global>The addresses that the peer is listening on.
protocols: Vec<String, Global>The list of protocols supported by the peer, e.g. /ipfs/ping/1.0.0.