Enum libp2p::kad::Quorum [−][src]
pub enum Quorum {
One,
Majority,
All,
N(NonZeroUsize),
}Expand description
A quorum w.r.t. the configured replication factor specifies the minimum number of distinct nodes that must be successfully contacted in order for a query to succeed.
Variants
N(NonZeroUsize)Trait Implementations