Struct libp2p::kad::handler::KademliaHandler [−][src]
pub struct KademliaHandler<TUserData> { /* fields omitted */ }Expand description
Protocol handler that manages substreams for the Kademlia protocol on a single connection with a peer.
The handler will automatically open a Kademlia substream with the remote for each request we make.
It also handles requests made by the remote.
Implementations
pub fn new(
config: KademliaHandlerConfig,
endpoint: ConnectedPoint
) -> KademliaHandler<TUserData>[src]
pub fn new(
config: KademliaHandlerConfig,
endpoint: ConnectedPoint
) -> KademliaHandler<TUserData>[src]Create a KademliaHandler using the given configuration.