Enum libp2p::kad::kbucket::NodeStatus [−][src]
pub enum NodeStatus {
Connected,
Disconnected,
}Expand description
The status of a node in a bucket.
The status of a node in a bucket together with the time of the last status change determines the position of the node in a bucket.
Variants
The node is considered connected.
The node is considered disconnected.