Struct libp2p::kad::kbucket::KBucketRef [−][src]
pub struct KBucketRef<'a, TKey, TVal> {
pub index: BucketIndex,
pub bucket: &'a mut KBucket<TKey, TVal>,
}Expand description
A reference to a bucket in a KBucketsTable.
Fields
index: BucketIndexbucket: &'a mut KBucket<TKey, TVal>Implementations
Returns the minimum inclusive and maximum inclusive Distance for
this bucket.
Returns the number of entries in the bucket.
Returns true if the bucket has a pending node.
Tests whether the given distance falls into this bucket.
Generates a random distance that falls into this bucket.
Together with a known key a (e.g. the local key), a random distance d for
this bucket w.r.t k gives rise to the corresponding (random) key b s.t.
the XOR distance between a and b is d. In other words, it gives
rise to a random key falling into this bucket. See key::Key::for_distance.
Returns an iterator over the entries in the bucket.