Struct libp2p::kad::protocol::KadPeer [−][src]
pub struct KadPeer {
pub public_key: PublicKey,
pub node_id: PeerId,
pub multiaddrs: Vec<Multiaddr, Global>,
pub connection_ty: KadConnectionType,
pub certificates: Vec<Certificate, Global>,
}Expand description
Information about a peer, as known by the sender.
Fields
public_key: PublicKeynode_id: PeerIdIdentifier of the peer.
multiaddrs: Vec<Multiaddr, Global>The multiaddresses that the sender think can be used in order to reach the peer.
connection_ty: KadConnectionTypeHow the sender is connected to that remote.
certificates: Vec<Certificate, Global>Trait Implementations