Struct libp2p::kad::record::ProviderRecord [−][src]
pub struct ProviderRecord {
pub key: Key,
pub provider: PeerId,
pub expires: Option<Instant>,
pub addresses: Vec<Multiaddr, Global>,
}Expand description
A record stored in the DHT whose value is the ID of a peer who can provide the value on-demand.
Note: Two ProviderRecords as well as their corresponding hashes are
equal iff their key and provider fields are equal. See the Hash and
PartialEq implementations.
Fields
key: KeyThe key whose value is provided by the provider.
provider: PeerIdThe provider of the value for the key.
expires: Option<Instant>The expiration time as measured by a local, monotonic clock.
addresses: Vec<Multiaddr, Global>The known addresses that the provider may be listening on.
Implementations
Creates a new provider record for insertion into a RecordStore.
Checks whether the provider record is expired w.r.t. the given Instant.