Struct libp2p::kad::PeerRecord [−][src]
A record either received by the given peer or retrieved from the local record store.
Fields
peer: Option<PeerId>The peer from whom the record was received. None if the record was
retrieved from local storage.
record: RecordTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.