Enum libp2p::mdns::MdnsEvent [−][src]
pub enum MdnsEvent {
Discovered(DiscoveredAddrsIter),
Expired(ExpiredAddrsIter),
}Expand description
Event that can be produced by the Mdns behaviour.
Variants
Discovered nodes through mDNS.
The given combinations of PeerId and Multiaddr have expired.
Each discovered record has a time-to-live. When this TTL expires and the address hasn’t
been refreshed, we remove it from the list and emit it as an Expired event.