Struct libp2p::mdns::MdnsConfig[][src]

pub struct MdnsConfig {
    pub ttl: Duration,
    pub query_interval: Duration,
}

Fields

ttl: Duration

TTL to use for mdns records.

query_interval: Duration

Interval at which to poll the network for new peers. This isn’t necessary during normal operation but avoids the case that an initial packet was lost and not discovering any peers until a new peer joins the network. Receiving an mdns packet resets the timer preventing unnecessary traffic.