Struct libp2p::noise::NoiseAuthenticated [−][src]
pub struct NoiseAuthenticated<P, C, R> where
C: Zeroize, { /* fields omitted */ }Expand description
A NoiseAuthenticated transport upgrade that wraps around any
NoiseConfig handshake and verifies that the remote identified with a
RemoteIdentity::IdentityKey, aborting otherwise.
See NoiseConfig::into_authenticated.
On success, the upgrade yields the PeerId obtained from the
RemoteIdentity. The output of this upgrade is thus directly suitable
for creating an authenticated
transport for use with a Network.