Struct libp2p::noise::ProtocolParams [−][src]
pub struct ProtocolParams(_);
The parameters of a Noise protocol, consisting of a choice for a handshake pattern as well as DH, cipher and hash functions.