Struct libp2p::plaintext::PlainText2Config [−][src]
pub struct PlainText2Config {
pub local_public_key: PublicKey,
}Expand description
PlainText2Config is an insecure connection handshake for testing purposes only, implementing
the libp2p plaintext connection handshake specification.
Fields
local_public_key: PublicKeyTrait Implementations
impl<C> InboundUpgrade<C> for PlainText2Config where
C: AsyncRead + AsyncWrite + Send + Unpin + 'static, [src]
impl<C> InboundUpgrade<C> for PlainText2Config where
C: AsyncRead + AsyncWrite + Send + Unpin + 'static, [src]type Output = (PeerId, PlainTextOutput<C>)
type Output = (PeerId, PlainTextOutput<C>)Output after the upgrade has been successfully negotiated and the handshake performed.
type Error = PlainTextError
type Error = PlainTextErrorPossible error during the handshake.
type Future = Pin<Box<dyn Future<Output = Result<<PlainText2Config as InboundUpgrade<C>>::Output, <PlainText2Config as InboundUpgrade<C>>::Error>> + 'static + Send, Global>>
type Future = Pin<Box<dyn Future<Output = Result<<PlainText2Config as InboundUpgrade<C>>::Output, <PlainText2Config as InboundUpgrade<C>>::Error>> + 'static + Send, Global>>Future that performs the handshake with the remote.
pub fn upgrade_inbound(
self,
socket: C,
<PlainText2Config as UpgradeInfo>::Info
) -> <PlainText2Config as InboundUpgrade<C>>::Future[src]
pub fn upgrade_inbound(
self,
socket: C,
<PlainText2Config as UpgradeInfo>::Info
) -> <PlainText2Config as InboundUpgrade<C>>::Future[src]After we have determined that the remote supports one of the protocols we support, this method is called to start the handshake. Read more
impl<C> OutboundUpgrade<C> for PlainText2Config where
C: AsyncRead + AsyncWrite + Send + Unpin + 'static, [src]
impl<C> OutboundUpgrade<C> for PlainText2Config where
C: AsyncRead + AsyncWrite + Send + Unpin + 'static, [src]type Output = (PeerId, PlainTextOutput<C>)
type Output = (PeerId, PlainTextOutput<C>)Output after the upgrade has been successfully negotiated and the handshake performed.
type Error = PlainTextError
type Error = PlainTextErrorPossible error during the handshake.
type Future = Pin<Box<dyn Future<Output = Result<<PlainText2Config as OutboundUpgrade<C>>::Output, <PlainText2Config as OutboundUpgrade<C>>::Error>> + 'static + Send, Global>>
type Future = Pin<Box<dyn Future<Output = Result<<PlainText2Config as OutboundUpgrade<C>>::Output, <PlainText2Config as OutboundUpgrade<C>>::Error>> + 'static + Send, Global>>Future that performs the handshake with the remote.
pub fn upgrade_outbound(
self,
socket: C,
<PlainText2Config as UpgradeInfo>::Info
) -> <PlainText2Config as OutboundUpgrade<C>>::Future[src]
pub fn upgrade_outbound(
self,
socket: C,
<PlainText2Config as UpgradeInfo>::Info
) -> <PlainText2Config as OutboundUpgrade<C>>::Future[src]After we have determined that the remote supports one of the protocols we support, this method is called to start the handshake. Read more
type Info = &'static [u8]
type Info = &'static [u8]Opaque type representing a negotiable protocol.
type InfoIter = Once<<PlainText2Config as UpgradeInfo>::Info>
type InfoIter = Once<<PlainText2Config as UpgradeInfo>::Info>Iterator returned by protocol_info.
Returns the list of protocols that are supported. Used during the negotiation process.