Struct libp2p::pnet::PnetConfig [−][src]
pub struct PnetConfig { /* fields omitted */ }Expand description
Private network configuration
Implementations
upgrade a connection to use pre shared key encryption.
the upgrade works by both sides exchanging 24 byte nonces and then encrypting subsequent traffic with XSalsa20