Struct libp2p::pnet::PreSharedKey [−][src]
pub struct PreSharedKey(_);
A pre-shared key, consisting of 32 bytes of random data.
Implementations
Compute PreSharedKey fingerprint identical to the go-libp2p fingerprint. The computation of the fingerprint is not specified in the spec.
This provides a way to check that private keys are properly configured without dumping the key itself to the console.