Enum libp2p::request_response::OutboundFailure [−][src]
pub enum OutboundFailure {
DialFailure,
Timeout,
ConnectionClosed,
UnsupportedProtocols,
}Expand description
Possible failures occurring in the context of sending an outbound request and receiving the response.
Variants
The request could not be sent because a dialing attempt failed.
The request timed out before a response was received.
It is not known whether the request may have been received (and processed) by the remote peer.
The connection closed before a response was received.
It is not known whether the request may have been received (and processed) by the remote peer.
The remote supports none of the requested protocols.