Struct libp2p::request_response::RequestId [−][src]
pub struct RequestId(_);
The ID of an inbound or outbound request.
Note: RequestId’s uniqueness is only guaranteed between two
inbound and likewise between two outbound requests. There is no
uniqueness guarantee in a set of both inbound and outbound
RequestIds nor in a set of inbound or outbound requests
originating from different RequestResponse behaviours.