Enum libp2p::request_response::throttled::Event [−][src]
pub enum Event<Req, Res, CRes = Res> {
Event(RequestResponseEvent<Req, Res, CRes>),
TooManyInboundRequests(PeerId),
ResumeSending(PeerId),
}Expand description
A Wrapper around RequestResponseEvent.
Variants
Event(RequestResponseEvent<Req, Res, CRes>)A regular request-response event.
TooManyInboundRequests(PeerId)We received more inbound requests than allowed.
ResumeSending(PeerId)When previously reaching the send limit of a peer, this event is eventually emitted when sending is allowed to resume.