Enum libp2p::swarm::DialPeerCondition [−][src]
#[non_exhaustive]
pub enum DialPeerCondition {
Disconnected,
NotDialing,
Always,
}Expand description
The available conditions under which a new dialing attempt to
a peer is initiated when requested by NetworkBehaviourAction::DialPeer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
A new dialing attempt is initiated only if the peer is currently considered disconnected, i.e. there is no established connection and no ongoing dialing attempt.
If there is an ongoing dialing attempt, the addresses reported by
NetworkBehaviour::addresses_of_peer are added to the ongoing
dialing attempt, ignoring duplicates.
A new dialing attempt is initiated only if there is currently no ongoing dialing attempt, i.e. the peer is either considered disconnected or connected but without an ongoing dialing attempt.
If there is an ongoing dialing attempt, the addresses reported by
NetworkBehaviour::addresses_of_peer are added to the ongoing
dialing attempt, ignoring duplicates.
A new dialing attempt is always initiated, only subject to the configured connection limits.