Struct libp2p::wasm_ext::ffi::Connection [−][src]
#[repr(transparent)]pub struct Connection { /* fields omitted */ }
Type of the object that represents an open connection with a remote.
Implementations
Returns an iterator of JavaScript Promises that resolve to ArrayBuffer objects
(or resolve to null, see below). These ArrayBuffer objects contain the data that the
remote has sent to us. If the remote closes the connection, the iterator must produce
a Promise that resolves to null.
Writes data to the connection. Returns a Promise that resolves when the connection is
ready for writing again.
If the Promise produces an error, the writing side of the connection is considered
unrecoverable and the connection should be closed as soon as possible.
Guaranteed to only be called after the previous write promise has resolved.
Methods from Deref<Target = JsValue>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
If this JS value is a string value, this function copies the JS string
value into wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Tests whether this JS value is undefined
Tests whether the type of this JS value is function.