Struct libp2p::kad::protocol::KademliaProtocolConfig [−][src]
pub struct KademliaProtocolConfig { /* fields omitted */ }Expand description
Configuration for a Kademlia connection upgrade. When applied to a connection, turns this
connection into a Stream + Sink whose items are of type KadRequestMsg and KadResponseMsg.
Implementations
Returns the configured protocol name.
Modifies the protocol name used on the wire. Can be used to create incompatibilities between networks on purpose.
Modifies the maximum allowed size of a single Kademlia packet.