Struct libp2p::mdns::MdnsConfig [−][src]
Fields
ttl: DurationTTL to use for mdns records.
query_interval: DurationInterval at which to poll the network for new peers. This isn’t necessary during normal operation but avoids the case that an initial packet was lost and not discovering any peers until a new peer joins the network. Receiving an mdns packet resets the timer preventing unnecessary traffic.