Trait libp2p::TransportExt [−][src]
pub trait TransportExt: Transport { fn with_bandwidth_logging(
self
) -> (BandwidthLogging<Self>, Arc<BandwidthSinks>)
where
Self: Sized, { ... } }
Trait automatically implemented on all objects that implement Transport. Provides some
additional utilities.
Provided methods
fn with_bandwidth_logging(self) -> (BandwidthLogging<Self>, Arc<BandwidthSinks>) where
Self: Sized, [src]
fn with_bandwidth_logging(self) -> (BandwidthLogging<Self>, Arc<BandwidthSinks>) where
Self: Sized, [src]Adds a layer on the Transport that logs all trafic that passes through the sockets
created by it.
This method returns an Arc<BandwidthSinks> that can be used to retreive the total number
of bytes transferred through the sockets.